@@ -3,7 +3,7 @@ Hyperscience saas client library
 """
 
 from .api.api_controller import ApiController
-from .api.request_handler import ContentType
+from .api.request_handler import ContentType, DataSupportedMediaType, PayloadSupportedMediaType
 from .auth.model import CredentialsProvider, EnvironmentCredentialsProvider
 from .config.configuration import Configuration
 from .utils.logger import HyperscienceLogging
@@ -15,4 +15,6 @@ __all__ = [
     'EnvironmentCredentialsProvider',
     'Configuration',
     'HyperscienceLogging',
+    'DataSupportedMediaType',
+    'PayloadSupportedMediaType',
 ]
