@@ -8,7 +8,7 @@ from requests import Response
 from ..auth.model.credentials import CredentialsBase, EnvironmentCredentialsProvider
 from ..config.configuration import Configuration
 from .model.http_verb import HttpVerb
-from .request_handler import _RequestHandler, DataSupportedMediaType, PayloadSupportedMediaType
+from .request_handler import DataSupportedMediaType, PayloadSupportedMediaType, _RequestHandler
 
 
 class ApiController:
