@@ -1,7 +1,7 @@
 """
 Singleton module utils
 """
-from typing import Dict, Any
+from typing import Any, Dict
 
 
 class Singleton(type):
